Trait rust_sc2::distance::Center [−][src]
pub trait Center: Iterator + Sized where
Self::Item: Into<Point2>, { fn center(self) -> Option<Point2> { ... } }
Helper trait for iterator of points, used to find center of these points.
Provided methods
fn center(self) -> Option<Point2>[src]
Returns center of all iterated points or None if iterator is empty.