rust_sc2

Module game_data

Information about units, ablities, upgrades, buffs and effects provided by API stored here.

Structs

  • Information about specific ability.
  • Information about specific buff.
  • Cost of an item (UnitTypeId or UpgradeId) in resources, supply and time.
  • Information about specific effect.
  • All the data about different ids stored here. Can be accessed through game_data field.
  • Information about specific unit type.
  • Information about specific upgrade.
  • Weapon’s characteristic.

Enums

  • Possible target of ability, needed when giving commands to units.
  • Differents attributes of units.
  • Possible target of unit’s weapon.