pub struct GameInfo {
pub map_name: String,
pub map_name_path: String,
pub mod_names: Vec<String>,
pub local_map_path: String,
pub players: FxHashMap<u32, PlayerInfo>,
pub map_size: Size,
pub pathing_grid: PixelMap,
pub terrain_height: Rc<ByteMap>,
pub placement_grid: PixelMap,
pub playable_area: Rect,
pub start_locations: Vec<Point2>,
pub map_center: Point2,
}Expand description
Structure where all map information stored.
Fields
map_name: StringMap name bot playing on, which depends on sc2 localization language.
map_name_path: StringMap name bot playing on, which depends on file name.
mod_names: Vec<String>Mods used on that map.
local_map_path: StringPath to the map on current computer.
players: FxHashMap<u32, PlayerInfo>Players on this map, mapped by their ids.
map_size: SizeFull size of the map.
pathing_grid: PixelMapGrid with information about pathable tiles on that map.
terrain_height: Rc<ByteMap>Grid with information about terrain height on that map.
placement_grid: PixelMapGrid with information about buildable tiles on that map.
playable_area: RectUsually maps have some unplayable area around it, where units can’t exist. This rectangle is only playble area on that map.
start_locations: Vec<Point2>All starting locations of opponents.
map_center: Point2Center of the map.