rust_sc2::player

Enum Race

pub enum Race {
    Terran,
    Zerg,
    Protoss,
    Random,
}
Representation of game races (your gender in SC2).

Variants



Terran

Brutal mens, who try to survive in this world.



Zerg

Ruthless insects of incredibly big size. What a nightmare?



Protoss

Kinda high-tech guys, who build cannons and batteries near your base “just for scouting”.



Random

Use when you didn’t decide your race yet or just want to play them all.

Implementations

Source

impl Race

pub fn is_terran(self) -> bool

pub fn is_zerg(self) -> bool

pub fn is_protoss(self) -> bool

pub fn is_random(self) -> bool