Struct rust_sc2::PlayerSettings [−][src]
pub struct PlayerSettings<'a> {
pub race: Race,
pub name: Option<&'a str>,
pub raw_affects_selection: bool,
pub raw_crop_to_playable_area: bool,
}Settings that must be provided by a player when joining a game.
if name is None, it’ll be shown as “foo(whatever)” in game.
if raw_affects_selection is true, bot will select units to which it gives orders.
if raw_crop_to_playable_area is true, maps will be crooped to the size of
self.game_info.playable_area.
Defaults:
name: None
raw_affects_selection: false
raw_crop_to_playable_area: false
Fields
race: Racename: Option<&'a str>raw_affects_selection: boolraw_crop_to_playable_area: boolImplementations
impl<'a> PlayerSettings<'a>[src]
pub fn new(race: Race) -> Self[src]
Constructs new settings with given Race.
pub fn with_name(self, name: &'a str) -> Self[src]
Sets name of the player.
pub fn raw_affects_selection(self, val: bool) -> Self[src]
Sets raw_affects_selection to a given value.
pub fn raw_crop_to_playable_area(self, val: bool) -> Self[src]
Sets raw_crop_to_playable_area to a given value.